@@ -353,12 +353,14 @@ def main():
 
     # Service-specific arguments
     service_parsers = {
-        "queueworker": start_parser.add_argument_group("Queue Worker"),
         "dirwatcher": start_parser.add_argument_group("Directory Watcher"),
-        "missionstats": start_parser.add_argument_group("Mission Stats Monitor"),
         "machinestats": start_parser.add_argument_group("Machine Stats Service"),
-        "vyomlistener": start_parser.add_argument_group("Vyom Listener"),
+        "mavproxyhq": start_parser.add_argument_group("Mavproxyhq Service"),
+        "missionstats": start_parser.add_argument_group("Mission Stats Monitor"),
+        "queueworker": start_parser.add_argument_group("Queue Worker"),
+        "robotstat": start_parser.add_argument_group("Robot Stats"),
         "rospublisher": start_parser.add_argument_group("Ros Publisher"),
+        "vyomlistener": start_parser.add_argument_group("Vyom Listener"),
     }
 
     # Arguments for queueworker
@@ -534,9 +536,14 @@ def main():
 
         if args.service == "machinestats":
             pass
+        
+        if args.service == "mavproxyhq":
+            pass
 
         if args.service == "rospublisher":
             pass
+        if args.service == "robotstat":
+            pass
 
         service_class = AVAILABLE_SERVICES[args.service]
         success, instance_id, instance_name = manager.start_service(
