@@ -2,8 +2,10 @@ from vyomcloudbridge.services.queue_worker import QueueWorker
 from vyomcloudbridge.services.dir_watcher import DirWatcher
 from vyomcloudbridge.services.mission_stats import MissionStats
 from vyomcloudbridge.services.machine_stats import MachineStats
+from vyomcloudbridge.services.mavproxy_hq import MavproxyHq
 from vyomcloudbridge.services.vyom_listener import VyomListener
 from vyomcloudbridge.services.ros_publisher import RosPublisher
+from vyomcloudbridge.services.robot_stats import RobotStat
 from typing import Dict, Type
 
 
@@ -12,6 +14,8 @@ AVAILABLE_SERVICES: Dict[str, Type] = {
     "dirwatcher": DirWatcher,
     "missionstats": MissionStats,
     "machinestats": MachineStats,
+    "mavproxyhq": MavproxyHq,
     "vyomlistener": VyomListener,
     "rospublisher": RosPublisher,
+    "robotstat": RobotStat,    
 }
