@@ -276,7 +276,7 @@ class AwsiotMqttListener(AbcListener):
 
             if len(topic_parts) == 5:
                 self.logger.debug(
-                    f"topic_parts[3] {topic_parts[3]} topic_parts[1] {topic_parts[1]} topic_parts[2]: {topic_parts[2]}"
+                    f"topic_parts 1 {topic_parts[1]} 2: {topic_parts[2]} 3: {topic_parts[3]}"
                 )
                 self.logger.debug(f"msg {msg} ")
                 self.handle_message(
