@@ -167,7 +167,7 @@ class MachineStats(ServiceAbstract):
                 properties=pika.BasicProperties(delivery_mode=2),
             )
 
-            self.logger.info(
+            self.logger.debug(
                 f"Set buffer: data_size={data_size}, data_size_uploaded={data_size_uploaded}"
             )
         except pika.exceptions.DuplicateGetOkCallback as e:
@@ -312,7 +312,7 @@ class MachineStats(ServiceAbstract):
                 expiration=self.expiration,
             )
 
-            self.logger.debug("Machine stats publish SUCCESSFUL")
+            self.logger.info("HEARTBEAT")
             return True
 
         except Exception as e:
@@ -381,9 +381,7 @@ class MachineStats(ServiceAbstract):
                     new_data_size_uploaded = new_data_size
                     self.logger.info(f"On all_data_uploaded...")
                     self._set_current_buffer(new_data_size, new_data_size_uploaded)
-                    self.logger.info(
-                        f"On all_data_uploaded, set data size: {new_data_size}, uploaded: {new_data_size_uploaded}"
-                    )
+                    self.logger.info("ZERO BUFFER")
                     return
             except Exception as e:
                 loopcount -= 1
@@ -441,7 +439,7 @@ class MachineStats(ServiceAbstract):
                         total_size_enques, total_size_deques
                     )
                 else:  # no changes in buffer, also check, message count in queue_main
-                    self.logger.info(
+                    self.logger.debug(
                         f"No changes in buffer, checking queue_main {main_data_queue} size, with sleep {self.rabbit_mq_api_sync_delay}"
                     )
                     time.sleep(
