@@ -2,7 +2,7 @@ import pika
 import json
 import logging
 from datetime import datetime, timezone
-from typing import List, Dict, Any, Optional, Union
+from typing import List, Dict, Any, Optional, Tuple, Union
 import threading
 import time
 
@@ -60,7 +60,7 @@ class MissionStats(ServiceAbstract):
         self.machine_config = Configs.get_machine_config()
         self.machine_id = self.machine_config.get("machine_id", "-") or "-"
         self.organization_id = self.machine_config.get("organization_id", "-") or "-"
-        self.data_source_name = "mission_stats"
+        self.data_source_stats = "mission_stats"
 
         self.machine_stats = MachineStats()
         # Thread attributes
@@ -435,7 +435,7 @@ class MissionStats(ServiceAbstract):
                 organization_id=self.organization_id,
                 machine_id=self.machine_id,
                 mission_id=id,
-                data_source=self.data_source_name,
+                data_source=self.data_source_stats,
                 date=date,
                 project_id=default_project_id,
             )
@@ -445,7 +445,7 @@ class MissionStats(ServiceAbstract):
                 "topic": f"{mission_upload_dir}/{filename}.json",
                 "message_type": "json",
                 "destination_ids": ["s3"],
-                "data_source": self.data_source_name,
+                "data_source": self.data_source_stats,
                 # meta data
                 "buffer_key": str(id),
                 "buffer_size": 0,
@@ -463,7 +463,7 @@ class MissionStats(ServiceAbstract):
         except Exception as e:
             self.logger.error(f"Error updating current mission: {str(e)}")
 
-    def get_current_mission(self) -> Optional[Dict[str, Any]]:
+    def get_current_mission(self) -> Tuple[Optional[Dict[str, Any]], Optional[str]]:
         """
         Retrieve the current mission details from RabbitMQ.
 
@@ -479,7 +479,7 @@ class MissionStats(ServiceAbstract):
                 return None, error_message
 
             method_frame, _, body = self.rmq_channel.basic_get(
-                queue="current_mission", auto_ack=False
+                queue=self.current_mission_queue, auto_ack=False
             )
 
             mission_detail = None
@@ -493,8 +493,8 @@ class MissionStats(ServiceAbstract):
                 )
             return mission_detail, None
         except Exception as e:
-            error_message = f"Warning getting current mission: {str(e)}"
-            self.logger.warning(error_message)
+            error_message = f"Error getting current mission: {str(e)}"
+            self.logger.error(error_message)
             return None, error_message
 
     def start_mission(
@@ -607,7 +607,7 @@ class MissionStats(ServiceAbstract):
                 organization_id=self.organization_id,
                 machine_id=self.machine_id,
                 mission_id=id,
-                data_source=self.data_source_name,
+                data_source=self.data_source_stats,
                 date=date,
                 project_id=default_project_id,
             )
@@ -617,7 +617,7 @@ class MissionStats(ServiceAbstract):
                 "topic": f"{mission_upload_dir}/{filename}.json",
                 "message_type": "json",
                 "destination_ids": ["s3"],
-                "data_source": self.data_source_name,
+                "data_source": self.data_source_stats,
                 # meta data
                 "buffer_key": str(id),
                 "buffer_size": 0,
@@ -681,7 +681,7 @@ class MissionStats(ServiceAbstract):
                         organization_id=self.organization_id,
                         machine_id=self.machine_id,
                         mission_id=existing_mission_id,
-                        data_source=self.data_source_name,
+                        data_source=self.data_source_stats,
                         date=date,
                         project_id=default_project_id,
                     )
@@ -693,7 +693,7 @@ class MissionStats(ServiceAbstract):
                         "topic": f"{mission_upload_dir}/{filename}.json",
                         "message_type": "json",
                         "destination_ids": ["s3"],
-                        "data_source": self.data_source_name,
+                        "data_source": self.data_source_stats,
                         # meta data
                         "buffer_key": str(existing_mission_id),
                         "buffer_size": 0,
@@ -733,12 +733,12 @@ class MissionStats(ServiceAbstract):
     #         now = datetime.now(timezone.utc)
     #         date = now.strftime("%Y-%m-%d")
     #         filename = int(time.time() * 1000)
-    #         # mission_upload_dir = f"{self.machine_config['organization_id']}/{date}/{default_project_id}/{self.data_source_name}/{self.machine_id}/{mission_id}" # TODO
+    #         # mission_upload_dir = f"{self.machine_config['organization_id']}/{date}/{default_project_id}/{self.data_source_stats}/{self.machine_id}/{mission_id}" # TODO
     #         mission_upload_dir: str = get_mission_upload_dir(
     #             organization_id=self.organization_id,
     #             machine_id=self.machine_id,
     #             mission_id=mission_id,
-    #             data_source=self.data_source_name,
+    #             data_source=self.data_source_stats,
     #             date=date,
     #             project_id={default_project_id},
     #         )
@@ -748,7 +748,7 @@ class MissionStats(ServiceAbstract):
     #             "topic": f"{mission_upload_dir}/{filename}.json",
     #             "message_type": "json",
     #             "destination_ids": ["s3"],
-    #             "data_source": self.data_source_name,
+    #             "data_source": self.data_source_stats,
     #             # meta data
     #             "buffer_key": str(mission_id),
     #             "buffer_size": 0,  # TODO
@@ -774,12 +774,12 @@ class MissionStats(ServiceAbstract):
             now = datetime.now(timezone.utc)
             date = now.strftime("%Y-%m-%d")
             filename = int(time.time() * 1000)
-            # mission_upload_dir = f"{self.machine_config['organization_id']}/{date}/{default_project_id}/{self.data_source_name}/{self.machine_id}/{mission_id}" # TODO
+            # mission_upload_dir = f"{self.machine_config['organization_id']}/{date}/{default_project_id}/{self.data_source_stats}/{self.machine_id}/{mission_id}" # TODO
             mission_upload_dir: str = get_mission_upload_dir(
                 organization_id=self.organization_id,
                 machine_id=self.machine_id,
                 mission_id=mission_id,
-                data_source=self.data_source_name,
+                data_source=self.data_source_stats,
                 date=date,
                 project_id=default_project_id,
             )
@@ -789,7 +789,7 @@ class MissionStats(ServiceAbstract):
                 "topic": f"{mission_upload_dir}/{filename}.json",
                 "message_type": "json",
                 "destination_ids": ["s3"],
-                "data_source": self.data_source_name,
+                "data_source": self.data_source_stats,
                 # meta data
                 "buffer_key": str(mission_id),
                 "buffer_size": 0,  # TODO
@@ -932,7 +932,7 @@ class MissionStats(ServiceAbstract):
         try:
             # Get the mission data for mission_id
             self.logger.info(
-                f"publishing {self.data_source_name}... for mission_id: {mission_id}"
+                f"publishing {self.data_source_stats}... for mission_id: {mission_id}"
             )
             if isinstance(mission_id, int):
                 mission_id = str(mission_id)
@@ -947,12 +947,12 @@ class MissionStats(ServiceAbstract):
             now = datetime.now(timezone.utc)
             date = now.strftime("%Y-%m-%d")
             filename = int(time.time() * 1000)
-            # mission_upload_dir = f"{self.machine_config['organization_id']}/{date}/{default_project_id}/{self.data_source_name}/{self.machine_id}/{mission_id}" # TODO
+            # mission_upload_dir = f"{self.machine_config['organization_id']}/{date}/{default_project_id}/{self.data_source_stats}/{self.machine_id}/{mission_id}" # TODO
             mission_upload_dir: str = get_mission_upload_dir(
                 organization_id=self.organization_id,
                 machine_id=self.machine_id,
                 mission_id=mission_id,
-                data_source=self.data_source_name,
+                data_source=self.data_source_stats,
                 date=date,
                 project_id=default_project_id,
             )
@@ -964,7 +964,7 @@ class MissionStats(ServiceAbstract):
                 "topic": f"{mission_upload_dir}/{filename}.json",
                 "message_type": "json",
                 "destination_ids": ["s3"],
-                "data_source": self.data_source_name,
+                "data_source": self.data_source_stats,
                 # meta data
                 "buffer_key": mission_id,
                 "buffer_size": 0,
@@ -996,12 +996,12 @@ class MissionStats(ServiceAbstract):
     #         now = datetime.now(timezone.utc)
     #         date = now.strftime("%Y-%m-%d")
     #         filename = int(time.time() * 1000)
-    #         # mission_upload_dir = f"{self.machine_config['organization_id']}/{date}/{default_project_id}/{self.data_source_name}/{self.machine_id}/{mission_id}" # TODO
+    #         # mission_upload_dir = f"{self.machine_config['organization_id']}/{date}/{default_project_id}/{self.data_source_stats}/{self.machine_id}/{mission_id}" # TODO
     #         mission_upload_dir: str = get_mission_upload_dir(
     #             organization_id=self.organization_id,
     #             machine_id=self.machine_id,
     #             mission_id=mission_id,
-    #             data_source=self.data_source_name,
+    #             data_source=self.data_source_stats,
     #             date=current_mission.get("mission_date", date),
     #             project_id=current_mission.get("campaign_id", default_project_id),
     #         )
@@ -1011,7 +1011,7 @@ class MissionStats(ServiceAbstract):
     #             "topic": f"{mission_upload_dir}/{filename}.json",
     #             "message_type": "json",
     #             "destination_ids": ["s3"],
-    #             "data_source": self.data_source_name,
+    #             "data_source": self.data_source_stats,
     #             # meta data
     #             "buffer_key": str(mission_id),
     #             "buffer_size": 0,
