@@ -147,8 +147,9 @@ class QueueWriterFile:
                 )
 
             message_body = json.dumps(file_info_data)
+            file_properties_topic = f"{file_dir}/file_properties/{filename}.json"
             headers = {
-                "topic": f"{file_dir}/file_properties/{filename}.json",
+                "topic": file_properties_topic,
                 "message_type": "json",
                 "destination_ids": destination_ids,
                 "data_source": data_source,
@@ -160,6 +161,9 @@ class QueueWriterFile:
             self.rabbit_mq.enqueue_message(
                 message=message_body, headers=headers, priority=priority
             )
+            self.logger.info(
+                f"Data enqueued to {file_properties_topic}, with priority: {priority}"
+            )
 
             # Send file content
             if should_chunk:
@@ -186,6 +190,9 @@ class QueueWriterFile:
 
                     except Exception as e:
                         self.logger.error("Error in publishing chunk-", i, e)
+                self.logger.info(
+                    f"Data enqueued to all {chunk_dir}/{filename}_*.bin, with priority: {priority}"
+                )
                 if merge_chunks:
                     s3_prop_key = f"{file_dir}/file_properties/{filename}.json"
                     self.chunk_merger.on_chunk_file_arrive(s3_prop_key)
@@ -206,6 +213,9 @@ class QueueWriterFile:
                     self.rabbit_mq.enqueue_message(
                         message=message_body, headers=headers, priority=priority
                     )
+                    self.logger.info(
+                        f"Data enqueued to {file_dir}/{filename}.{file_extension}, with priority: {priority}"
+                    )
                 except Exception as e:
                     self.logger.error(f"Error in publishing file: {e}")
         except Exception as e:
