@@ -98,7 +98,7 @@ class RootStore(ServiceAbstract):  # Not in use
         Args:
             key: The queue name to ensure exists
         """
-        if not self._ensure_connection():
+        if not self._ensure_connection() or not self.rmq_channel:
             raise Exception("Could not establish connection")
 
         self._validate_key(key)
@@ -126,16 +126,19 @@ class RootStore(ServiceAbstract):  # Not in use
             data: Any JSON serializable data to store (dict, list, int, str, etc.)
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
-            self.logger.info(f"Setting data for key {key}")
+            self.logger.debug(f"Setting data for key {key}")
 
             self._validate_key(key)
 
             # Ensure queue exists
             self._ensure_queue(key)
 
+            # Clear existing data
+            self.delete_data(key)
+
             # Prepare data for storage
             # If it's a dict, add timestamp directly
             if isinstance(data, dict):
@@ -163,7 +166,7 @@ class RootStore(ServiceAbstract):  # Not in use
                     content_type="application/json",
                 ),
             )
-            self.logger.info(f"Set data in queue: {key}")
+            self.logger.debug(f"Set data for key: {key}")
         except ValueError as e:
             # Re-raise validation errors
             raise
@@ -181,7 +184,7 @@ class RootStore(ServiceAbstract):  # Not in use
             Data (any type) or None if not found
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             self._validate_key(key)
@@ -207,7 +210,7 @@ class RootStore(ServiceAbstract):  # Not in use
                 self.rmq_channel.basic_nack(
                     delivery_tag=method_frame.delivery_tag, requeue=True
                 )
-                self.logger.info(f"Retrieved data from queue: {key}")
+                self.logger.debug(f"Retrieved data from queue: {key}")
             return data
         except ValueError as e:
             # Re-raise validation errors
@@ -216,7 +219,9 @@ class RootStore(ServiceAbstract):  # Not in use
             self.logger.error(f"Error getting data from {key}: {str(e)}")
             return None
 
-    def update_data(self, key: str, data: Any):
+    def update_data(
+        self, key: str, data: Any
+    ):  # Depreciated, will not be removed in future
         """
         Update data in the specified queue.
         This first clears any existing data in the queue.
@@ -227,7 +232,7 @@ class RootStore(ServiceAbstract):  # Not in use
             data: Any JSON serializable data to store (dict, list, int, str, etc.)
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             self.logger.info(f"updating data for key {key}")
@@ -267,7 +272,7 @@ class RootStore(ServiceAbstract):  # Not in use
                     content_type="application/json",
                 ),
             )
-            self.logger.info(f"Updated data in queue: {key}")
+            self.logger.info(f"Updated data for key: {key}")
         except ValueError as e:
             # Re-raise validation errors
             raise
@@ -282,7 +287,7 @@ class RootStore(ServiceAbstract):  # Not in use
             key: The queue name to delete data from
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             self._validate_key(key)
@@ -295,7 +300,7 @@ class RootStore(ServiceAbstract):  # Not in use
                 if not method_frame:
                     break
 
-            self.logger.info(f"Deleted all data from queue: {key}")
+            self.logger.debug(f"Deleted all data from queue: {key}")
         except ValueError as e:
             # Re-raise validation errors
             raise
@@ -340,6 +345,18 @@ class RootStore(ServiceAbstract):  # Not in use
             except Exception as e:
                 self.logger.error(f"Error closing connection: {str(e)}")
 
+    def cleanup(self):
+        """
+        Cleanup the service.
+        """
+        try:
+            if self.rmq_conn and self.rmq_conn.is_open:
+                self.rmq_conn.close()
+                self.logger.info("General store service stopped")
+            self.logger.info("General store service cleaned up")
+        except Exception as e:
+            self.logger.error(f"Error closing connection: {str(e)}")
+
     def is_healthy(self):
         """
         Check if the service is healthy.
@@ -354,10 +371,11 @@ class RootStore(ServiceAbstract):  # Not in use
     def __del__(self):
         """Destructor called by garbage collector to ensure resources are cleaned up, when object is about to be destroyed"""
         try:
-            self.logger.error(
-                "Destructor called by garbage collector to cleanup QueueWriterFile"
-            )
-            self.stop()
+            if self.is_healthy():
+                self.logger.error(
+                    "Destructor called by garbage collector to cleanup RootStore"
+                )
+                self.stop()
         except Exception as e:
             pass
 
@@ -509,7 +527,7 @@ def set_data(key: str, data: Any, rabbitmq_url: str = DEFAULT_RABBITMQ_URL) -> b
     """
     rmq_conn = None
     try:
-        logger.info(f"Setting data for key: {key}")
+        logger.debug(f"Setting data for key: {key}")
         _validate_key(key)
 
         # Setup connection
@@ -548,7 +566,7 @@ def set_data(key: str, data: Any, rabbitmq_url: str = DEFAULT_RABBITMQ_URL) -> b
                 content_type="application/json",
             ),
         )
-        logger.info(f"Set data in queue: {key}")
+        logger.debug(f"Set data for key: {key}")
         return True
     except ValueError as e:
         # Re-raise validation errors
@@ -622,7 +640,7 @@ def update_data(key: str, data: Any, rabbitmq_url: str = DEFAULT_RABBITMQ_URL) -
                 content_type="application/json",
             ),
         )
-        logger.info(f"Updated data in queue: {key}")
+        logger.info(f"Updated data for key: {key}")
         return True
     except ValueError as e:
         # Re-raise validation errors
@@ -713,97 +731,113 @@ def delete_data(key: str, rabbitmq_url: str = DEFAULT_RABBITMQ_URL) -> bool:
 def main():
     """Example of how to use the RootStore"""
     print("Starting general root store service example")
-
-    store = RootStore()
+    # from vyomcloudbridge.services.root_store import RootStore
+    root_store = RootStore()
 
     try:
         # Example: Store user details
-        # user_data = {
-        #     "id": 1,
-        #     "name": "Test User",
-        #     "email": "testuser@example.com",
-        #     "role": "operator",
-        # }
-        # store.update_data("user_details", user_data)
+        unset_key_example = root_store.get_data("unset_key_example")
+        print(f"Retrieved user: {unset_key_example}")
 
-        # # Retrieve the stored data
-        # retrieved_user = store.get_data("user_details")
-        # print(f"Retrieved user: {retrieved_user}")
+        user_data = {
+            "id": 1,
+            "name": "Test User",
+            "email": "testuser@example.com",
+            "role": "operator",
+        }
+        root_store.set_data("user_details", user_data)
 
-        # # Update with new data
-        # new_user_data = {
-        #     "id": 2,
-        #     "name": "Another User",
-        #     "email": "another@example.com",
-        #     "role": "admin",
-        # }
-        # store.update_data("user_details", new_user_data)
+        # Retrieve the stored data
+        retrieved_user = root_store.get_data("user_details")
+        print(f"Retrieved user: {retrieved_user}")
 
-        # # Retrieve the updated data
-        # updated_user = store.get_data("user_details")
-        # print(f"Updated user: {updated_user}")
+        # Update with new data
+        new_user_data = {
+            "id": 2,
+            "name": "Another User",
+            "email": "another@example.com",
+            "role": "admin",
+        }
+        root_store.set_data("user_details", new_user_data)
 
-        # # Delete the data
-        # store.delete_data("user_details")
+        # Retrieve the updated data
+        updated_user = root_store.get_data("user_details")
+        print(f"Updated user: {updated_user}")
 
-        # # Verify deletion
-        # after_delete = store.get_data("user_details")
-        # print(f"After delete: {after_delete}")
+        # Delete the data
+        root_store.delete_data("user_details")
 
-        # # Try to use a reserved key (should raise ValueError)
-        # try:
-        #     store.update_data("current_user", user_data)
-        # except ValueError as e:
-        #     print(f"Expected error: {e}")
+        # Verify deletion
+        after_delete = root_store.get_data("user_details")
+        print(f"After delete: {after_delete}")
 
-        # # Store different types of data
-        # config_data = {"theme": "dark", "notifications": True, "auto_update": False}
-        # store.update_data("app_config", config_data)
+        # Try to use a reserved key (should raise ValueError)
+        try:
+            print(f"Try to use a reserved key (should expect ValueError).....")
+            root_store.set_data("current_user", user_data)
+        except ValueError as e:
+            print(f"Expected error: {e}")
 
-        # # Retrieve the config data
-        # retrieved_config = store.get_data("app_config")
-        # print(f"Retrieved config: {retrieved_config}")
+        # Store different types of data
+        config_data = {"theme": "dark", "notifications": True, "auto_update": False}
+        root_store.set_data("app_config", config_data)
 
-        # # Store an integer value
-        # store.update_data("temp_id", 2)
-        # temp_data = store.get_data("temp_id")
-        # print(f"Retrieved temp_data: {temp_data}")
+        # Retrieve the config data
+        retrieved_config = root_store.get_data("app_config")
+        print(f"Retrieved config: {retrieved_config}")
 
-        # # Store a string
-        # store.update_data("message", "Hello, RabbitMQ!")
-        # message = store.get_data("message")
-        # print(f"Retrieved message: {message}")
+        # Store an integer value
+        root_store.set_data("temp_id", 2)
+        temp_data = root_store.get_data("temp_id")
+        print(f"Retrieved temp_data: {temp_data}")
 
-        # # Store a list
-        # store.update_data("colors", ["red", "green", "blue"])
-        # colors = store.get_data("colors")
-        # print(f"Retrieved colors: {colors}")
+        # Store a string
+        root_store.set_data("message", "Hello, RabbitMQ!")
+        message = root_store.get_data("message")
+        print(f"Retrieved message: {message}")
 
-        user_key = "user_data"
-
-        # First data
-        user_data = "Akash"
-        update_data(user_key, user_data)  # Use update_data instead of set_data
-        retrieved_user = get_data(user_key)
-        print(f"Retrieved user_data 1: {retrieved_user}")
-
-        # Second data
-        user_data = {"id": 3, "name": "Akash", "age": 25}
-        update_data(user_key, user_data)  # Use update_data instead of set_data
-        retrieved_user = get_data(user_key)
-        print(f"Retrieved user_data 2: {retrieved_user}")
-
-        # Third data
-        user_data = 3
-        update_data(user_key, user_data)  # Use update_data instead of set_data
-        retrieved_user = get_data(user_key)
-        print(f"Retrieved user_data 3: {retrieved_user}")
+        # Store a list
+        root_store.set_data("colors", ["red", "green", "blue"])
+        colors = root_store.get_data("colors")
+        print(f"Retrieved colors: {colors}")
 
+        location = {
+            "lat": 76.987934,
+            "long": 76.937954,
+            "alt": 930,
+            "timestamp": "93u4983",
+        }
+        health = {"status": 1, "message": ""}
+        root_store.set_data("location", location)
+        root_store.set_data("health", health)
+    except Exception as e:
+        print("Error occured -", {str(e)})
     finally:
         # Clean up
-        store.stop()
+        root_store.cleanup()
 
-    print("Completed")
+    # try:
+    #     user_key = "user_data"
+    #     # First data
+    #     user_data = "Akash"
+    #     update_data(user_key, user_data)  # Use update_data instead of set_data
+    #     retrieved_user = get_data(user_key)
+    #     print(f"Retrieved user_data 1: {retrieved_user}")
+
+    #     # Second data
+    #     user_data = {"id": 3, "name": "Akash", "age": 25}
+    #     update_data(user_key, user_data)  # Use update_data instead of set_data
+    #     retrieved_user = get_data(user_key)
+    #     print(f"Retrieved user_data 2: {retrieved_user}")
+
+    #     # Third data
+    #     user_data = 3
+    #     update_data(user_key, user_data)  # Use update_data instead of set_data
+    #     retrieved_user = get_data(user_key)
+    #     print(f"Retrieved user_data 3: {retrieved_user}")
+    # except Exception as e:
+    #     print("Error occured -", {str(e)})
+    #     pass
 
 
 if __name__ == "__main__":
