@@ -13,17 +13,23 @@ from typing import Callable
 import rclpy
 from rclpy.callback_groups import ReentrantCallbackGroup, MutuallyExclusiveCallbackGroup
 from rclpy.node import Node
-from rclpy.qos import QoSProfile, QoSReliabilityPolicy, HistoryPolicy, QoSDurabilityPolicy
+from rclpy.qos import (
+    QoSProfile,
+    QoSReliabilityPolicy,
+    HistoryPolicy,
+    QoSDurabilityPolicy,
+)
 from rosidl_runtime_py import set_message_fields
 import sensor_msgs.msg
 from std_msgs.msg import String
+from datetime import datetime
 
 # === Local Application Imports ===
 sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
 
 from utils.generate_summary import Summariser
 from vyomcloudbridge.constants.constants import default_mission_id
-from vyomcloudbridge.services.mission_stats import MissionStats
+from vyomcloudbridge.utils.mission_utils import MissionUtils
 from vyomcloudbridge.services.queue_writer_json import QueueWriterJson
 from vyomcloudbridge.utils.common import ServiceAbstract
 from vyomcloudbridge.utils.logger_setup import setup_logger
@@ -93,15 +99,15 @@ class SendDataToServer(Node, ServiceAbstract):
             String, "update_topic_list", self.update_topic_list_machine_callback, 10
         )
         self.topic_list_sub
-        
+
         self.topic_list_sub_os = self.create_subscription(
             String, "update_topic_list_os", self.update_topic_list_mission_callback, 10
         )
         self.topic_list_sub_os
-        
+
         self._freq_tracker = defaultdict(lambda: {"last_time": None})
         self.logger.info("SendDataToServer node initialized successfully.")
-           
+
     def update_topic_list_mission_callback(self, msg):
         try:
             # Parse JSON array from message
@@ -120,64 +126,74 @@ class SendDataToServer(Node, ServiceAbstract):
         updated_subscription_list = []
         for received_topic in new_topics_list:
             matching_topic_config = next(
-                (topic for topic in available_topics if topic["name"] == received_topic["name"]),
-                None
+                (
+                    topic
+                    for topic in available_topics
+                    if topic["name"] == received_topic["name"]
+                ),
+                None,
             )
             if matching_topic_config:
-                # Override stored settings with any provided in the incoming message
-                matching_topic_config.update({
-                    "is_subscribed": received_topic.get("is_subscribed", matching_topic_config["is_subscribed"]),
-                    "frequency": received_topic.get("frequency", matching_topic_config["frequency"]),
-                    "send_live": received_topic.get("send_live", matching_topic_config["send_live"]),
-                    "save_locally": received_topic.get("save_locally", matching_topic_config["save_locally"])
-                })
-                updated_subscription_list.append(matching_topic_config)
-        
+                # Merge is_subscribed and destinations
+                updated_config = dict(matching_topic_config)  # start from file
+                updated_config["is_subscribed"] = received_topic.get(
+                    "is_subscribed", matching_topic_config.get("is_subscribed", False)
+                )
+
+                # Merge destinations per destination type
+                if "destinations" in received_topic:
+                    for dest_key, dest_vals in received_topic["destinations"].items():
+                        if dest_key in updated_config["destinations"]:
+                            updated_config["destinations"][dest_key].update(dest_vals)
+                        else:
+                            updated_config["destinations"][dest_key] = dest_vals
+
+                updated_subscription_list.append(updated_config)
+
         new_topics = {topic["topic"] for topic in updated_subscription_list}
-        self.logger.info(f"Received new_topics mission: {new_topics}")
-        
-        
+        self.logger.info(f"New topics set: {new_topics}")
+
         # Get current mission_subscribers
-        current_subscriber_map = {sub.topic_name: sub for sub in self.mission_subscribers}
+        current_subscriber_map = {
+            sub.topic_name: sub for sub in self.mission_subscribers
+        }
         current_topics = set(current_subscriber_map.keys())
 
-        # # Early exit if no changes
         if current_topics == new_topics:
             self.logger.info("Topic list unchanged. No update needed.")
             return
 
         self.logger.info(f"New topics: {new_topics}, Current topics: {current_topics}")
-        # Build the new subscriber list before destroying any
+
+        # Keep existing subs for still-needed topics
         self.mission_subscribers = [
             sub for sub in self.mission_subscribers if sub.topic_name in new_topics
         ]
 
-        # Unsubscribe from topics that are no longer needed
+        # Unsubscribe from removed topics
         for topic_name in current_topics - new_topics:
             self.logger.info(f"Unsubscribing from topic: {topic_name}")
             self.destroy_subscription(current_subscriber_map[topic_name])
 
-        self.logger.info(f"Subscribing to new topic: ")
-        
-        # Subscribe to new topics
+        # Subscribe to newly added topics
         for topic in updated_subscription_list:
             if topic["topic"] not in current_topics:
                 self.logger.info(
-                    f"Subscribing to new topic: "
-                    f"{topic['name']} | {topic['data_type']} | {topic['topic']} | "
-                    f"live: {topic['send_live']} | freq: {topic['frequency']} | save: {topic['save_locally']}"
+                    f"Subscribing to: {topic['name']} | {topic['data_type']} | {topic['topic']} "
+                    f"| destinations: {topic['destinations']}"
                 )
                 self.create_dynamic_subscribers(topic, self.mission_subscribers)
-                
 
     def update_topic_list_machine_callback(self, msg):
         new_topic_list = self.get_subcribed_topics()
-        self.logger.info(f"[Machine] Received new topic list: {new_topic_list}")
+        new_mission_topic_list = self.get_mission_subcribed_topics()
+        self.logger.info(f"[Machine] Received new topic list: {new_mission_topic_list}")
 
         new_topics = {topic["topic"] for topic in new_topic_list}
-        current_subscriber_map = {sub.topic_name: sub for sub in self.machine_subscribers}
+        current_subscriber_map = {
+            sub.topic_name: sub for sub in self.machine_subscribers
+        }
         current_topics = set(current_subscriber_map.keys())
-        
 
         # Early exit if no changes
         if current_topics == new_topics:
@@ -197,15 +213,17 @@ class SendDataToServer(Node, ServiceAbstract):
         # Subscribe to new topics
         for topic in new_topic_list:
             if topic["topic"] not in current_topics:
-                self.logger.debug(f"[Machine] Subscribing to new topic: {topic['topic']}")
+                self.logger.debug(
+                    f"[Machine] Subscribing to new topic: {topic['topic']}"
+                )
                 self.create_dynamic_subscribers(topic, self.machine_subscribers)
 
     def create_subscribers(self):
         self.is_running = True
         self.logger.debug(f"topics {self.get_subcribed_topics()}")
-        for topic in self.get_subcribed_topics():
-            self.logger.info(f"Subscribing to topic: {topic}")
-            self.create_dynamic_subscribers(topic,self.machine_subscribers)
+        for topic_details in self.get_subcribed_topics():
+            self.logger.info(f"Subscribing to topic: {topic_details}")
+            self.create_dynamic_subscribers(topic_details, self.machine_subscribers)
 
     def get_subcribed_topics(self):
         """
@@ -219,7 +237,10 @@ class SendDataToServer(Node, ServiceAbstract):
         """
 
         topic_list = self.load_topic_list_from_file()
-        return [topics for topics in topic_list if topics["is_subscribed"]]
+        return [
+            topics for topics in topic_list
+            if topics.get("is_subscribed", False) or topics.get("is_subscribe_on_mission", False)
+        ]
 
     def load_topic_list_from_file(self):
         """
@@ -251,34 +272,39 @@ class SendDataToServer(Node, ServiceAbstract):
 
     def send_summary(self, summary):
         self.logger.debug(f"Summary {summary}")
-        
-        self.writer.write_message(
-            message_data=summary,
-            data_type="json",
-            data_source="mission_summary",
-            destination_ids=["gcs_mav"],
-            filename=None,
-            mission_id=self.mission_id,
-            project_id=None,
-            priority=3,
-            merge_chunks=True,
-            expiry_time_ms=5000,
-            background=True
-        )
 
         self.writer.write_message(
-            message_data=summary,
-            data_type="json",
+            background=True,
             data_source="mission_summary",
-            destination_ids=["s3", "gcs_mqtt"],
+            data_type="json",
+            destination_ids=["gcs"],
+            expiry_time_ms=5000,
             filename=None,
-            mission_id=self.current_mission.get("id"),
-            project_id=None,
-            priority=3,
             merge_chunks=True,
-            send_live=True,
-            background=True
+            message_data=summary,
+            mission_id=self.mission_id,
+            priority=3,
+            project_id=None,
         )
+        success, error = self.writer.write_message(
+            background=True,
+            data_source="mission_summary",
+            data_type="json",
+            destination_ids=["s3"],  # ["s3"]
+            filename=None,  # nullable or epoch time
+            merge_chunks=True,  # True for telemetry data
+            message_data=summary,  # json data
+            mission_id=self.mission_id,  # mission_id
+            priority=3,
+            project_id=None,
+            send_live=True,
+        )
+        if success:
+            self.logger.debug(f"Successfully sent {success} for topic: mission_summary")
+        elif error:
+            self.logger.error(f"Not sent. Error {error} for topic: mission_summary")
+        else:
+            self.logger.info(f"Not sent. Status unknown for topic: mission_summary")
 
     def update_mission_id(self):
         self.current_mission, error = self.get_current_mission()
@@ -294,17 +320,136 @@ class SendDataToServer(Node, ServiceAbstract):
         if self.current_mission.get("mission_status") == 2:
             if self.summariser.get_mission_mode() == 1:
                 self.logger.debug("stopped")
-                # self.summariser.print_summary()
-                # self.send_summary(self.summariser.print_summary())
-                # self.summariser.set_mission_mode(2)
-                # self.summariser.reset()
+                self.summariser.print_summary()
+                self.send_summary(self.summariser.print_summary())
+                self.summariser.set_mission_mode(2)
+                self.summariser.reset()
 
         return default_mission_id
 
-    def create_listener_function(self, f_msg_data_type, f_topic_name, f_topic, f_send_live, f_data_upload_frequency, f_save_locally):
+    def get_or_preprocess_message(self, f_msg, f_topic_name, f_msg_data_type):
+        """
+        Returns cached preprocessed data if within max_age_ms, otherwise regenerates.
+        """
+        current_value = converter.convert(f_msg_data_type, 1, f_msg)
+
+        cleaned_value = self.replace_nan_with_null(current_value)
+        epoch_ms = int(time.time() * 1000)
+
+        if f_msg_data_type == "sensor_msgs.msg.Image":
+            filename = f"{epoch_ms}.jpeg"
+            data_type = "image"
+            extracted_data = cleaned_value
+        else:
+            filename = f"{epoch_ms}.json"
+            data_type = "json"
+
+            timenow = time.time()
+            timestamp_sec = int(timenow)
+            timestamp_nsec = int((timenow - timestamp_sec) * 1_000_000_000)
+
+            extracted_data = {
+                "timestamp": {
+                    "seconds": timestamp_sec,
+                    "nanoseconds": timestamp_nsec,
+                },
+                "key": f_topic_name,
+                "mission_id": self.mission_id,
+                "data": {},
+            }
+            extracted_data["data"] = cleaned_value
+
+        self.logger.info(
+            f"Logs data type: {type(cleaned_value)}, filename: {filename}, data_type: {data_type} epoch_ms"
+        )
+
+        # Get mission id
+        self.mission_id = self.update_mission_id()
+        self.logger.info(f"self.mission_id: {self.mission_id}")
+
+        return {
+            "filename": filename,
+            "data_type": data_type,
+            "extracted_data": extracted_data,
+            "topic_name": f_topic_name,
+        }
+
+    def save_locally_or_send(
+        self,
+        f_processed_payload,
+        f_can_send_buffered,
+        f_can_send_live,
+        f_destination,
+        f_is_local,
+    ):
+        """
+        Saves the message locally or sends it to a remote server based on the configuration.
+        Args:
+            msg: The incoming message to be processed.
+            f_topic_name (str): The name of the topic from which the message was received.
+            f_msg_data_type: The data type of the message.
+            upload_freq (float): The frequency at which data should be uploaded.
+            msg_freq (float): The frequency of incoming messages.
+        """
+        filename = f_processed_payload["filename"]
+        data_type = f_processed_payload["data_type"]
+        extracted_data = f_processed_payload["extracted_data"]
+        f_topic_name = f_processed_payload["topic_name"]
+
+        self.logger.info(f"Processing message for topic: {f_topic_name}")
+
+        if f_is_local:
+            self.logger.info(f"Saving locally for: {f_topic_name}")
+            now = datetime.now()
+            local_path = f"/var/log/vyomcloudbridge/mission_data/{self.mission_id}/{now.strftime('%Y-%m-%d')}/{now.strftime('%H')}/{f_topic_name}"
+            os.makedirs(os.path.dirname(local_path), exist_ok=True)
+
+            if data_type == "image":
+                ts = int(time.time())
+                ts_str = f"{ts}_000000000"
+                filename = f"image_{ts_str}.jpeg"
+
+                os.makedirs(local_path, exist_ok=True)
+
+                full_path = os.path.join(local_path, filename)
+                with open(full_path, "wb") as image_file:
+                    image_file.write(extracted_data)
+            else:
+                ts = extracted_data["timestamp"]
+                ts_str = f"{ts['seconds']}_{ts['nanoseconds']}"
+
+                with open(local_path, "a") as file:
+                    json.dump(extracted_data, file)
+                    file.write("\n")
+
+        elif f_can_send_buffered or f_can_send_live:
+            self.logger.info(f"Sending data for: {f_topic_name}")
+            success, error = self.writer.write_message(
+                message_data=extracted_data,  # json data
+                filename=filename,  # nullable or epoch time
+                data_source=f_topic_name,  # telemetry, mission_summary
+                data_type=data_type,  # file, video, image
+                mission_id=self.mission_id,  # mission_id
+                priority=1,  # 1 for velocity data, battery topic, and ROS data
+                destination_ids=[f_destination],  # ["s3"]
+                merge_chunks=True,  # True for telemetry data
+                send_persistent=(not f_can_send_live),
+                send_live=f_can_send_live,
+            )
+            if success:
+                self.logger.debug(f"Successfully sent {success} for topic: {f_topic_name}")
+            elif error:
+                self.logger.error(f"Not sent. Error {error} for topic: {f_topic_name}")
+            else:
+                self.logger.info(f"Not sent. Status unknown for topic: {f_topic_name}")
+        else:
+            self.logger.warning(f"Cannot send or save data for: {f_topic_name}")
+
+    def create_listener_function(
+        self, f_topic_details
+    ):
         """
         Creates a listener function for processing incoming messages of a specific type and topic.
-
         The generated listener function performs the following:
             - Converts the incoming message to the desired format using a converter.
             - Extracts a timestamp from the message header if available.
@@ -314,111 +459,96 @@ class SendDataToServer(Node, ServiceAbstract):
               topic, mission ID, and the converted data.
             - Writes the processed data to a destination using the `self.writer.write_message` method.
         """
-
+        f_msg_data_type = f_topic_details["data_type"]
+        f_topic_name = f_topic_details["name"]
+        f_topic = f_topic_details["topic"]
+        f_destinations = f_topic_details["destinations"]
+        f_is_subscribed = f_topic_details["is_subscribed"]
+        f_is_subscribe_on_mission = f_topic_details["is_subscribe_on_mission"]
+        
         # eg: f_msg_data_type=vyom_mission_msgs.msg.MissionStatus, f_topic_name=MISSION_TOPIC
         def callback(msg):
-            if self.current_mission.get("mission_status") == 1:
+            if self.current_mission is None:
+                l_current_mission = -1
+            else:
+                l_current_mission = self.current_mission.get("mission_status")
+                
+            if l_current_mission == 1:
                 self.logger.debug("Mission is in progress, updating summariser")
                 self.summariser.update(f_topic, msg)
+                
+            self.mission_id = self.update_mission_id()
 
-            self.logger.debug(f"Ros data processing for ros_topic: {f_topic_name}")
+            if f_is_subscribed:
+                self.logger.info(f"Processing and sending data for topic: {f_topic_name}")
+            else:
+                self.logger.info(f"Checking if is_subscribe_on_mission")
+                self.logger.info(f"self.current_mission.get('mission_status'): {l_current_mission}")
+                
+                if f_is_subscribe_on_mission and l_current_mission == 1:
+                    self.logger.info(f"Processing and sending data for topic: {f_topic_name} during mission")
+                else:
+                    self.logger.info(f"Not processing data for topic: {f_topic_name} as not subscribed and not during mission")
+                    return callback
+
+            self.logger.info(f"Ros data processing for ros_topic: {f_topic_name}")
 
             tracker = self._freq_tracker[f_topic_name]
             now = self._clock.now().nanoseconds / 1e9
-            should_log, upload_freq, msg_freq = should_throttle(tracker, f_data_upload_frequency, now)
-            
-            if should_log:
+
+            self.logger.info(f"Destinations: {f_destinations}")
+
+            eligible_destinations = []
+
+            # iterate over the destinations
+            for destination, rates in f_destinations.items():
+                self.logger.info(f"Processing destination: {destination} -> {rates}")
+                (
+                    can_send_buffered,
+                    can_send_live,
+                    buf_freq,
+                    live_freq,
+                    msg_freq,
+                    is_local,
+                ) = should_throttle(
+                    tracker, destination, rates["live"], rates["buffered"], now
+                )
                 self.logger.info(
-                    f"[{f_topic_name}] Msg Freq: {msg_freq:.2f} Hz | "
-                    f"Upload Freq: {upload_freq:.2f} Hz | Msg: {msg}"
+                    f"can_send_buffered: {can_send_buffered}, can_send_live: {can_send_live}, "
+                    f"buf_freq: {buf_freq}, live_freq: {live_freq}, msg_freq: {msg_freq}, is_local: {is_local}"
                 )
 
-                current_value = converter.convert(f_msg_data_type, 1, msg)
+                # Collect only those destinations we can send to
+                if is_local or can_send_buffered or can_send_live:
+                    eligible_destinations.append(
+                        {
+                            "destination": destination,
+                            "can_send_buffered": can_send_buffered,
+                            "can_send_live": can_send_live,
+                            "is_local": is_local,
+                        }
+                    )
 
-                cleaned_value = self.replace_nan_with_null(current_value)
-                epoch_ms = int(time.time() * 1000)
-
-                if (f_msg_data_type == "sensor_msgs.msg.Image" and f_msg_data_type.__module__ == "sensor_msgs.msg.Image"):
-                    filename = f"{epoch_ms}.jpeg"
-                    data_type = "image"
-                    extracted_data = cleaned_value
-                else:
-                    filename = f"{epoch_ms}.json"
-                    data_type = "json"
-                    
-                    timenow = time.time()
-                    timestamp_sec = int(timenow)
-                    timestamp_nsec = int((timenow - timestamp_sec) * 1_000_000_000)
-
-                    extracted_data = {
-                        "timestamp": {
-                            "seconds": timestamp_sec,
-                            "nanoseconds": timestamp_nsec,
-                        },
-                        "key": f_topic_name,
-                        "mission_id": self.mission_id,
-                        "data": {},
-                    }
-                    extracted_data["data"] = cleaned_value
-
-                self.logger.debug(
-                    f"Logs data type: {type(cleaned_value)}, filename: {filename}, data_type: {data_type} epoch_ms"
+            # Only preprocess if there’s something to send
+            if eligible_destinations:
+                processed_payload = self.get_or_preprocess_message(
+                    msg, f_topic_name, f_msg_data_type
                 )
 
-                # Get mission id
-                self.mission_id = self.update_mission_id()
-                self.logger.info(f"self.mission_id: {self.mission_id}")
-
-                if f_save_locally:
-                    # Save the data locally
-                    self.logger.info(f"Saving locally for: {f_topic_name}")
-
-                    local_path = f"/var/log/vyomcloudbridge/mission_data/{self.mission_id}/{f_topic_name}"
-                    os.makedirs(os.path.dirname(local_path), exist_ok=True)
-                    with open(local_path, "a") as file:
-                        if data_type == "image":
-                            file.write(extracted_data)
-                        else:
-                            json.dump(extracted_data, file)
-
-                else:
-                    self.logger.info(f"Sending data for: {f_topic_name}")
-                    success, error = self.writer.write_message(
-                        message_data=extracted_data,  # json data
-                        filename=filename,  # nullable or epoch time
-                        data_source=f_topic_name,  # telemetry, mission_summary
-                        data_type=data_type,  # file, video, image
-                        mission_id=self.mission_id,  # mission_id
-                        priority=1,  # 1  for velocity data, battery topic, and ROS data
-                        destination_ids=["s3"],  # ["s3"]
-                        merge_chunks=True,  # True for telemetry data
-                        send_live=f_send_live,
+                for dest_info in eligible_destinations:
+                    self.save_locally_or_send(
+                        processed_payload,
+                        dest_info["can_send_buffered"],
+                        dest_info["can_send_live"],
+                        dest_info["destination"],
+                        dest_info["is_local"],
                     )
-                    self.writer.write_message(
-                        message_data=extracted_data,  # json data
-                        filename=filename,  # nullable or epoch time
-                        data_source=f_topic_name,  # telemetry, mission_summary
-                        data_type=data_type,  # file, video, image
-                        mission_id=self.mission_id,  # mission_id
-                        priority=1,  # 1  for velocity data, battery topic, and ROS data
-                        destination_ids=["gcs_mqtt"],  # ["s3"] ["gcs_mqtt" via mqtt]
-                        merge_chunks=True,  # True for telemetry data
-                        send_persistent=False,
-                        send_live=f_send_live,
-                    )
-                    if success:
-                        self.logger.debug(
-                            f"Successlly sent to S3 {success} for topic: {f_topic_name}"
-                        )
-                    elif error:
-                        self.logger.error(
-                            f"Not sent to S3. Error {error} for topic: {f_topic_name}"
-                        )
-                    else:
-                        self.logger.info(
-                            f"Not sent to S3. Status unknown for topic: {f_topic_name}"
-                        )
-                self.logger.info(f"Ros data processed for ros_topic: {f_topic_name}")
+            else:
+                self.logger.info(
+                    "No eligible destinations this cycle — skipping preprocessing."
+                )
+
+            self.logger.info(f"Ros data processed for ros_topic: {f_topic_name}")
 
         return callback
 
@@ -451,39 +581,39 @@ class SendDataToServer(Node, ServiceAbstract):
 
         return getattr(module, class_name)
 
-    def create_dynamic_subscribers(self, f_topic,f_subscribers):
+    def create_dynamic_subscribers(self, f_topic_details, f_subscribers):
         """
         Dynamically creates and adds a subscriber to the list of subscribers.
         This method takes a topic configuration, creates a subscription for the
         specified data type and topic path, and appends it to the `subscribers` list.
 
         Args:
-            f_topic (dict): A dictionary containing the topic configuration with the following keys:
+            f_topic_details (dict): A dictionary containing the topic configuration with the following keys:
                 - "data_type" (str): The fully qualified class name of the data type to subscribe to.
                 - "path" (str): The topic path to subscribe to.
                 - "name" (str): The name of the topic.
         """
         try:
-            if "camera" in f_topic['topic'].lower():
+            if "camera" in f_topic_details["topic"].lower():
                 qos_profile = self.camera_qos
             else:
                 qos_profile = self.m_qos
-                
+
             f_subscribers.append(
                 self.create_subscription(
-                    self.import_class_from_string(f_topic["data_type"]),
-                    f_topic["topic"],
-                    self.create_listener_function(
-                        f_topic["data_type"], f_topic["name"], f_topic["topic"], f_topic["send_live"], f_topic["frequency"], f_topic["save_locally"]
-                    ),
+                    self.import_class_from_string(f_topic_details["data_type"]),
+                    f_topic_details["topic"],
+                    self.create_listener_function(f_topic_details),
                     callback_group=self.callback_group,
                     qos_profile=qos_profile,
                 )
             )
-            self.logger.info(f"Subscribed to topic: {f_topic['topic']} with type: {f_topic['data_type']}")
+            self.logger.info(
+                f"Subscribed to topic: {f_topic_details['topic']} with type: {f_topic_details['data_type']}"
+            )
         except Exception as e:
             self.logger.error(
-                f"Failed to subscribe to topic: {f_topic['topic']} with type: {f_topic['data_type']}. Error: {e}"
+                f"Failed to subscribe to topic: {f_topic_details['topic']} with type: {f_topic_details['data_type']}. Error: {e}"
             )
 
     def subscriber_shutdown(self):
@@ -513,8 +643,8 @@ class RosPublisher(ServiceAbstract):
         self.logger.info("Initializing RosPublisher..")
         self.is_running = False
         self.spin_thread = None
-        self.mission_stats = MissionStats()
-        self.get_current_mission = self.mission_stats.get_current_mission
+        self.mission_utils = MissionUtils()
+        self.get_current_mission = self.mission_utils.get_current_mission
         try:
             rclpy.init(args=None)
         except Exception as e:
@@ -529,6 +659,7 @@ class RosPublisher(ServiceAbstract):
             self.is_running = True
 
             self.send_data_to_server.create_subscribers()
+
             def start_proccess():
                 rclpy.spin(self.send_data_to_server)
                 while self.is_running:
@@ -554,7 +685,7 @@ class RosPublisher(ServiceAbstract):
 
     def cleanup(self):
         try:
-            self.mission_stats.cleanup()
+            self.mission_utils.cleanup()
         except Exception as e:
             self.logger.error(f"----")
 
@@ -581,5 +712,6 @@ def main(args=None):
         data_streamer.stop()
     print("Completed SendDataToServer service example")
 
+
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
