@@ -1,10 +1,13 @@
 import threading
 import time
+import json
+import os
 from vyomcloudbridge.utils.configs import Configs
 from vyomcloudbridge.utils.logger_setup import setup_logger
 from vyomcloudbridge.senders.mav_sender import MavSender
 from vyomcloudbridge.senders.awsiot_mqtt_sender import AwsiotMqttSender
 
+
 class VyomSender:
     _instance = None
     _lock = threading.Lock()
@@ -33,30 +36,54 @@ class VyomSender:
             self.machine_config = Configs.get_machine_config()
             self.machine_id = self.machine_config.get("machine_id", "-") or "-"
             self.logger.info("Setting up all senders...")
-            self.senders = {"mqtt": AwsiotMqttSender(daemon=True), "mavlink": MavSender()}
+            self.senders = {
+                "mqtt": AwsiotMqttSender(daemon=True),
+                "mavlink": MavSender(),
+            }
             self.logger.info("Setup of all senders Done!")
             # TODO, need to handle gcs_mav, machine,
-            self.network = {
-                "s3": [
-                    {"device_id": "s3", "channel": "mqtt"},
-                ],
-                "hq_1": [
-                    {"device_id": "s3", "channel": "mqtt"},
-                ],
-                "gcs_mav": [
-                    {"device_id": "gcs_mav", "channel": "mavlink", "system_id": 255},
-                ],
-                "gcs_mqtt": [
-                    {"device_id": "gcs_mqtt", "channel": "mqtt"},
-                ],
-                "machine_59": [
-                    {"device_id": "machine_59", "channel": "mqtt"},
-                ],
-            }
+            self.network = self._load_network_config()
             self.logger.info("VyomSender started sucessfully!")
         except Exception as e:
             self.logger.error("VyomSender starting failed")
 
+    def _load_network_config(self):
+        """Load network configuration from networks.json file"""
+        try:
+            # Get the path to the constants directory relative to this file
+            current_dir = os.path.dirname(os.path.abspath(__file__))
+            constants_dir = os.path.join(current_dir, "..", "constants")
+            networks_file = os.path.join(constants_dir, "networks.json")
+
+            with open(networks_file, "r") as f:
+                network_config = json.load(f)
+                self.logger.info(
+                    "Successfully loaded network configuration from networks.json"
+                )
+                return network_config
+        except FileNotFoundError:
+            self.logger.error(
+                f"Networks configuration file not found at {networks_file}"
+            )
+            return {
+                "s3": [{"device_id": "s3", "channel": "mqtt"}],
+                "gcs_mqtt": [{"device_id": "gcs_mqtt", "channel": "mqtt"}],
+            }
+        except json.JSONDecodeError as e:
+            self.logger.error(f"Error parsing networks.json: {str(e)}")
+            return {
+                "s3": [{"device_id": "s3", "channel": "mqtt"}],
+                "gcs_mqtt": [{"device_id": "gcs_mqtt", "channel": "mqtt"}],
+            }
+        except Exception as e:
+            self.logger.error(
+                f"Unexpected error loading network configuration: {str(e)}"
+            )
+            return {
+                "s3": [{"device_id": "s3", "channel": "mqtt"}],
+                "gcs_mqtt": [{"device_id": "gcs_mqtt", "channel": "mqtt"}],
+            }
+
     def send_message(self, message, message_type, destination_ids, data_source, topic):
         """
         Send message to the destination ids
