@@ -660,7 +660,7 @@ def fetch_and_save_topics(interactive=True):
                 if not machine_model_id:
                     print("Error: Machine model ID not found in configuration file.")
                     print(
-                        f"Please delete {machine_config_file} and do `vyomcloudbridge setup` up again."
+                        f"Please delete {machine_config_file} and again do `vyomcloudbridge setup` from root user."
                     )
                     return (
                         False,
