@@ -1,7 +1,7 @@
 # vyomcloudbridge/utils/logger_setup.py
 import logging
 import os
-from vyomcloudbridge.constants.constants import log_dir
+from vyomcloudbridge.constants.constants import log_dir, log_file_name
 
 default_log_dir = os.path.expanduser(log_dir)
 
@@ -23,7 +23,7 @@ def setup_logger(
     )
 
     # file_handler = logging.FileHandler(os.path.join(log_dir, f"{name}.log"))
-    file_handler = logging.FileHandler(os.path.join(log_dir, "vyomcloudbridge.log"))
+    file_handler = logging.FileHandler(os.path.join(log_dir, log_file_name))
     file_handler.setFormatter(formatter)
     logger.addHandler(file_handler)
 
