@@ -48,6 +48,8 @@ class MissionUtils:
         self.data_source_stats = "mission_stats"
         self.data_source_mission = "mission_message"
         self.data_source_summary = "mission_summary"
+        self.current_mission_queue = "current_mission"
+        self.last_mission_queue = "last_mission"
 
     def generate_mission_id(self):
         try:
@@ -74,7 +76,10 @@ class MissionUtils:
             #     )
             # )
             self.rmq_channel = self.rmq_conn.channel()
-            self.rmq_channel.queue_declare(queue="current_mission", durable=True)
+            self.rmq_channel.queue_declare(
+                queue=self.current_mission_queue, durable=True
+            )
+            self.rmq_channel.queue_declare(queue=self.last_mission_queue, durable=True)
 
             self.logger.info("RabbitMQ connection established successfully")
         except Exception as e:
@@ -91,7 +96,9 @@ class MissionUtils:
             if not self.rmq_channel or self.rmq_channel.is_closed:
                 self.logger.info("Closed channel found, re-establishing...")
                 self.rmq_channel = self.rmq_conn.channel()
-                self.rmq_channel.queue_declare(queue="current_mission", durable=True)
+                self.rmq_channel.queue_declare(
+                    queue=self.current_mission_queue, durable=True
+                )
                 self.logger.info("Channel re-established successfully")
 
             return True
@@ -101,6 +108,40 @@ class MissionUtils:
             self.rmq_channel = None
             return False
 
+    def get_last_mission(self) -> Tuple[Optional[Dict[str, Any]], Optional[str]]:
+        """
+        Retrieve the current mission details from RabbitMQ.
+
+        Returns:
+            Tuple:
+                - dict or None: Current mission details if available, else None
+                - str or None: Error message if any issue occurs, else None
+        """
+        try:
+            if not self._ensure_connection() or not self.rmq_channel:
+                error_message = "Could not establish connection"
+                self.logger.error(error_message)
+                return None, error_message
+
+            method_frame, _, body = self.rmq_channel.basic_get(
+                queue=self.last_mission_queue, auto_ack=False
+            )
+
+            mission_detail = None
+            if method_frame:
+                mission_detail = json.loads(body.decode("utf-8"))
+                self.rmq_channel.basic_nack(
+                    delivery_tag=method_frame.delivery_tag, requeue=True
+                )
+                self.logger.info(
+                    f"Retrieved last mission: {mission_detail.get('id', 'unknown')}"
+                )
+            return mission_detail, None
+        except Exception as e:
+            error_message = f"Error getting last mission: {str(e)}"
+            self.logger.error(error_message)
+            return None, error_message
+
     def get_current_mission(self) -> Tuple[Optional[Dict[str, Any]], Optional[str]]:
         """
         Retrieve the current mission details from RabbitMQ.
@@ -117,7 +158,7 @@ class MissionUtils:
                 return None, error_message
 
             method_frame, _, body = self.rmq_channel.basic_get(
-                queue="current_mission", auto_ack=False
+                queue=self.current_mission_queue, auto_ack=False
             )
 
             mission_detail = None
@@ -131,8 +172,8 @@ class MissionUtils:
                 )
             return mission_detail, None
         except Exception as e:
-            error_message = f"Warning getting current mission: {str(e)}"
-            self.logger.warning(error_message)
+            error_message = f"Error getting current mission: {str(e)}"
+            self.logger.error(error_message)
             return None, error_message
 
     def start_mission(
@@ -261,14 +302,14 @@ class MissionUtils:
 
             while True:
                 method_frame, _, _ = self.rmq_channel.basic_get(
-                    queue="current_mission", auto_ack=True
+                    queue=self.current_mission_queue, auto_ack=True
                 )
                 if not method_frame:
                     break
 
             self.rmq_channel.basic_publish(
                 exchange="",
-                routing_key="current_mission",
+                routing_key=self.current_mission_queue,
                 body=json.dumps(mission_detail),
                 properties=pika.BasicProperties(
                     delivery_mode=2,  # make message persistent
@@ -318,12 +359,13 @@ class MissionUtils:
 
     def end_current_mission(self, destination_ids: List[Union[str, int]] = ["s3"]):
         """
-        Mark the current mission as completed and update RabbitMQ.
+        Mark the current mission as completed, move it to last_mission queue,
+        and remove it from current_mission queue.
 
         Returns:
             Tuple:
-                - success (bool): success, True if mission successfully marked as completed or no active mission found; False if error
-                - error_message (str): error message if there is any error, else None in case of success
+            - success (bool): True if mission successfully completed or no active mission found; False if error
+            - error_message (str): error message if there is any error, else None in case of success
         """
         try:
             if destination_ids and (
@@ -352,23 +394,34 @@ class MissionUtils:
                     existing_mission_id = mission_detail.get("id", None)
                     if existing_mission_id is None:
                         error_message = "Mission ID is None in the existing mission. Cannot mark it complete. Removing this object from cache."
-                        method_frame, _, _ = self.rmq_channel.basic_get(
-                            queue="current_mission", auto_ack=True
-                        )
+                        # Clear the current mission queue
+                        self._clear_queue(self.current_mission_queue)
                         return False, error_message
 
+                    # Mark mission as completed
                     mission_detail["mission_status"] = 2
+                    mission_detail["end_time"] = datetime.now(timezone.utc).isoformat()
 
+                    # Clear current mission queue (remove completed mission from current)
                     while True:
                         method_frame, _, _ = self.rmq_channel.basic_get(
-                            queue="current_mission", auto_ack=True
+                            queue=self.current_mission_queue, auto_ack=True
                         )
                         if not method_frame:
                             break
 
+                    # Clear last mission queue first (to store only the latest completed mission)
+                    while True:
+                        method_frame, _, _ = self.rmq_channel.basic_get(
+                            queue=self.last_mission_queue, auto_ack=True
+                        )
+                        if not method_frame:
+                            break
+
+                    # Add completed mission to last_mission queue
                     self.rmq_channel.basic_publish(
                         exchange="",
-                        routing_key="current_mission",
+                        routing_key=self.last_mission_queue,
                         body=json.dumps(mission_detail),
                         properties=pika.BasicProperties(
                             delivery_mode=2,  # make message persistent
@@ -376,54 +429,115 @@ class MissionUtils:
                         ),
                     )
 
-                    # Publish mission data in real time
-                    now = datetime.now(timezone.utc)
-                    date = now.strftime("%Y-%m-%d")
-                    filename = int(time.time() * 1000)
-                    mission_upload_dir: str = get_mission_upload_dir(
-                        organization_id=self.organization_id,
-                        machine_id=self.machine_id,
-                        mission_id=existing_mission_id,
-                        data_source=self.data_source_mission,
-                        date=date,
-                        project_id=default_project_id,
-                    )
-
                     # message_body = json.dumps(
                     #     {"mission": mission_detail, "data_stats": None}
                     # )
-                    message_body = json.dumps(mission_detail)
-                    headers = {
-                        "topic": f"{mission_upload_dir}/{filename}.json",
-                        "message_type": "json",
-                        "destination_ids": destination_ids,
-                        "data_source": self.data_source_mission,
-                        # meta data
-                        "buffer_key": str(existing_mission_id),
-                        "buffer_size": 0,
-                        "data_type": "json",
-                    }
-                    self.rabbit_mq.enqueue_message(
-                        message=message_body,
-                        headers=headers,
-                        priority=self.mission_live_priority,
-                    )
+                    try:
+                        # Publish mission completion data in real time
+                        now = datetime.now(timezone.utc)
+                        date = now.strftime("%Y-%m-%d")
+                        filename = int(time.time() * 1000)
+                        mission_upload_dir: str = get_mission_upload_dir(
+                            organization_id=self.organization_id,
+                            machine_id=self.machine_id,
+                            mission_id=existing_mission_id,
+                            data_source=self.data_source_mission,
+                            date=date,
+                            project_id=default_project_id,
+                        )
+
+                        message_body = json.dumps(mission_detail)
+                        headers = {
+                            "topic": f"{mission_upload_dir}/{filename}.json",
+                            "message_type": "json",
+                            "destination_ids": destination_ids,
+                            "data_source": self.data_source_mission,
+                            # meta data
+                            "buffer_key": str(existing_mission_id),
+                            "buffer_size": 0,
+                            "data_type": "json",
+                        }
+
+                        self.rabbit_mq.enqueue_message(
+                            message=message_body,
+                            headers=headers,
+                            priority=self.mission_live_priority,
+                        )
+
+                        self.logger.info(
+                            f"Mission with id={existing_mission_id} completed and moved to last_mission queue"
+                        )
+                        return True, None
+                    except Exception as e:
+                        rabbitmq_error = f"Could not complete the current mission with id={existing_mission_id}, error sending to message to rabbitmq, error: {str(e)}"
+                        self.logger.error(rabbitmq_error)
+
+                        mission_detail["mission_status"] = 1
+                        mission_detail.pop("end_time", None)
+
+                        self._clear_queue(self.current_mission_queue)
+
+                        self.rmq_channel.basic_publish(
+                            exchange="",
+                            routing_key=self.current_mission_queue,
+                            body=json.dumps(mission_detail),
+                            properties=pika.BasicProperties(
+                                delivery_mode=2,  # make message persistent
+                                content_type="application/json",
+                            ),
+                        )
+
+                        return False, rabbitmq_error
 
-                    self.logger.info(
-                        f"Current mission with id={existing_mission_id}, marked completed"
-                    )
-                    return True, None
                 else:
                     self.logger.info(f"No active mission found to mark completed")
+                    if mission_detail["mission_status"] == 2:
+                        self._move_mission_to_last_queue(mission_detail)
                     return True, None
             else:
                 self.logger.info(f"No active mission found to mark completed")
                 return True, None
+
         except Exception as e:
             error_message = f"Error updating current mission: {str(e)}"
             self.logger.error(error_message)
             return False, error_message
 
+    def _clear_queue(self, queue_name: str):
+        """Helper method to clear all messages from a queue, connection should be checked before this itself"""
+        try:
+            while True:
+                method_frame, _, _ = self.rmq_channel.basic_get(
+                    queue=queue_name, auto_ack=True
+                )
+                if not method_frame:
+                    break
+        except Exception as e:
+            self.logger.error(f"Error clearing queue {queue_name}: {str(e)}")
+
+    def _move_mission_to_last_queue(self, mission_detail: Dict[str, Any]):
+        """Helper method to move mission from current to last queue, connection should be checked before this itself"""
+        try:
+            # Clear current mission queue
+            self._clear_queue(self.current_mission_queue)
+
+            # Clear last mission queue (to store only the latest completed mission)
+            self._clear_queue(self.last_mission_queue)
+
+            # Add mission to last_mission queue
+            self.rmq_channel.basic_publish(
+                exchange="",
+                routing_key=self.last_mission_queue,
+                body=json.dumps(mission_detail),
+                properties=pika.BasicProperties(
+                    delivery_mode=2,
+                    content_type="application/json",
+                ),
+            )
+        except Exception as e:
+            self.logger.error(f"Error moving mission to last queue: {str(e)}")
+            raise
+
     def is_healthy(self):
         """
         Check if the service is healthy.
@@ -453,6 +567,7 @@ class MissionUtils:
 def main():
     # Example 1: Interective start and end mission
     from vyomcloudbridge.utils.mission_utils import MissionUtils
+
     mission_utils = MissionUtils()
     new_mission_id = mission_utils.generate_mission_id()
     print("Trying to start mission_id with-", new_mission_id)
@@ -460,7 +575,7 @@ def main():
         try:
             mission_start_time = datetime.now(timezone.utc).isoformat()
             mission_detail, start_mission_error = mission_utils.start_mission(
-                id = new_mission_id,
+                id=new_mission_id,
                 start_time=mission_start_time,
                 destination_ids=["s3", "gcs_mqtt"],
             )
@@ -510,6 +625,22 @@ def main():
             print("MissionUtils service interrupted by user.")
         except Exception as e:
             print(f"An error in ending current mission: {str(e)}")
+
+        print("\n\n\nNow let's try to fetch the curremt mission status")
+        current_mission_message, current_mission_error = (
+            mission_utils.get_current_mission()
+        )
+        if current_mission_error:
+            print(f"Error fetching current mission: {current_mission_error}")
+        else:
+            print(f"Current mission status: {current_mission_message}")
+
+        print("\n\n\nNow let's try to fetch the last mission status")
+        last_mission_message, last_mission_error = mission_utils.get_last_mission()
+        if last_mission_error:
+            print(f"Error fetching last mission: {last_mission_error}")
+        else:
+            print(f"Last mission status: {last_mission_message}")
     except Exception as e:
         print(f"An error occurred: {str(e)}")
     finally:
